@@ -37,6 +37,7 @@ pyorbit_check_ex(CORBA_Environment *ev)
 	any = ev->_any;
 	any._type = pyorbit_lookup_typecode(ev->_id);
 	instance = pyorbit_demarshal_any(&any);
+	any._type = NULL;
 	if (instance) {
 	    PyObject *stub, *attr;
 
@@ -136,20 +137,27 @@ create_system_exception(CORBA_TypeCode tc, PyObject *corbamod)
 }
 
 static PyObject *
-pyorbit_exception_init(PyObject *self, PyObject *args)
+pyorbit_exception_init(PyObject *s, PyObject *args)
 {
+    PyObject *self;
     gint len, i;
     PyObject *pytc, *obj;
     CORBA_TypeCode tc;
 
+    /* for the zero argument case, don't do anything */
+    len = PyTuple_Size(args);
+    if (len == 0) {
+	PyErr_SetString(PyExc_TypeError, "required argument 'self' missing");
+	return NULL;
+    }
+    self = PyTuple_GetItem(args, 0);
+
     /* make sure the exception has an "args" attribute */
     obj = PyTuple_New(0);
     PyObject_SetAttrString(self, "args", obj);
     Py_DECREF(obj);
 
-    /* for the zero argument case, don't do anything */
-    len = PyTuple_Size(args);
-    if (len == 0) {
+    if (len == 1) {
 	Py_INCREF(Py_None);
 	return Py_None;
     }
@@ -166,16 +174,16 @@ pyorbit_exception_init(PyObject *self, PyObject *args)
     tc = ((PyCORBA_TypeCode *)pytc)->tc;
     Py_DECREF(pytc);
 
-    if (tc->sub_parts != len) {
+    if (tc->sub_parts != len - 1) {
 	PyErr_Format(PyExc_TypeError, "expected %d arguments, got %d",
 		     tc->sub_parts, len);
 	return NULL;
     }
 
-    for (i = 0; i < len; i++) {
+    for (i = 1; i < len; i++) {
 	PyObject *item  = PyTuple_GetItem(args, i);
 
-	PyObject_SetAttrString(self, tc->subnames[i], item);
+	PyObject_SetAttrString(self, tc->subnames[i-1], item);
     }
     Py_INCREF(Py_None);
     return Py_None;
@@ -188,16 +196,17 @@ static PyMethodDef pyorbit_exception_init_methoddef = {
 void
 pyorbit_register_exceptions(PyObject *corbamod)
 {
-    PyObject *init;
+    PyObject *init_f, *init_m;
 
     /* base exception classes */
     pyorbit_exception = PyErr_NewException("CORBA.Exception",
 					   PyExc_RuntimeError, NULL);
     /* exception constructor */
-    init = PyDescr_NewMethod((PyTypeObject *)pyorbit_exception,
-			     &pyorbit_exception_init_methoddef);
-    PyObject_SetAttrString(pyorbit_exception, "__init__", init);
-    Py_DECREF(init);
+    init_f = PyCFunction_New(&pyorbit_exception_init_methoddef, NULL);
+    init_m = PyMethod_New(init_f, NULL, pyorbit_exception);
+    Py_DECREF(init_f);
+    PyObject_SetAttrString(pyorbit_exception, "__init__", init_m);
+    Py_DECREF(init_m);
 
     PyModule_AddObject(corbamod, "Exception", pyorbit_exception);
     pyorbit_system_exception = PyErr_NewException("CORBA.SystemException",
