@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4 -*-
  * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
- * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -108,6 +108,7 @@ typedef struct {
 extern PyTypeObject PyPortableServer_Servant_Type;
 void _pyorbit_register_skel(ORBit_IInterface *iinterface);
 
+extern PyTypeObject PyORBit_ObjectAdaptor_Type;
 extern PyTypeObject PyPortableServer_POA_Type;
 extern PyTypeObject PyPortableServer_POAManager_Type;
 PyObject *pyorbit_poa_new(PortableServer_POA poa);
@@ -116,4 +117,36 @@ PyObject *pyorbit_poamanager_new(PortableServer_POAManager poamanager);
 
 extern PortableServer_POA _pyorbit_poa;
 
+
+#define pyorbit_gil_state_ensure() (PyEval_ThreadsInitialized()? (PyGILState_Ensure()) : 0)
+
+#define pyorbit_gil_state_release(state) G_STMT_START { \
+    if (PyEval_ThreadsInitialized())                    \
+        PyGILState_Release(state);                      \
+    } G_STMT_END
+
+#define pyorbit_begin_allow_threads             \
+    G_STMT_START {                              \
+        PyThreadState *_save = NULL;            \
+        if (PyEval_ThreadsInitialized())        \
+            _save = PyEval_SaveThread();
+
+#define pyorbit_end_allow_threads               \
+        if (PyEval_ThreadsInitialized())        \
+            PyEval_RestoreThread(_save);        \
+    } G_STMT_END
+
+
+  /* pycorba-policy.c */
+
+typedef struct {
+    PyObject_VAR_HEAD
+    CORBA_Object objref;
+} PyCORBA_Policy;
+
+extern PyTypeObject PyCORBA_Policy_Type;
+
+PyObject * pycorba_policy_new(CORBA_Object policy);
+
+
 #endif
